==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/sv.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laddar förhandsvisning...",
    "Saved" : "Sparat",
    "Admin" : "Admin",
    "a safe home for all your data" : "En säker lagringsplats för all din data",
    "The given name is too long" : "Det angivna namnet är för långt",
    "The given web address is too long" : "Den angivna adressen är för lång",
    "The given slogan is too long" : "Den angivna slogan är för lång",
    "The given color is invalid" : "Den angivna färgen är inte tillgänglig",
    "No file uploaded" : "Ingen fil uppladdad",
    "Unsupported image type" : "Filtypen är ej giltig",
    "You are already using a custom theme" : "Du använder redan ett annat tema",
    "Theming" : "Teman",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teman gör det möjligt att enkelt skräddarsy utseendet på ditt moln. Detta kommer att synas för alla användare.",
    "Name" : "Namn",
    "Reset to default" : "Återställ till grundinställningar",
    "Web address" : "Webbadress",
    "Web address https://…" : "Webbadress https://...",
    "Slogan" : "Slogan",
    "Color" : "Färg",
    "Logo" : "Logotyp",
    "Upload new logo" : "Ladda upp ny logotyp",
    "Login image" : "Inloggningsbild",
    "Upload new login background" : "Ladda upp ny bakgrundsbild",
    "Remove background image" : "Ta bort bakgrundsbild",
    "reset to default" : "Återställ till standard",
    "Log in image" : "Inloggningsbild"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/sv.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laddar förhandsvisning...",
    "Saved" : "Sparat",
    "Admin" : "Admin",
    "a safe home for all your data" : "En säker lagringsplats för all din data",
    "The given name is too long" : "Det angivna namnet är för långt",
    "The given web address is too long" : "Den angivna adressen är för lång",
    "The given slogan is too long" : "Den angivna slogan är för lång",
    "The given color is invalid" : "Den angivna färgen är inte tillgänglig",
    "There is no error, the file uploaded with success" : "Det finns inga fel, uppladdning av filen lyckades ",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Uppladdningsfilen är för stor (upload_max_filesize i php.ini)",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-instruktionen specificerad i HTML-form",
    "The uploaded file was only partially uploaded" : "Den uppladdade filen laddades bara upp delvis",
    "No file was uploaded" : "Ingen fil laddades up",
    "Missing a temporary folder" : "Saknar en temporär mapp",
    "Failed to write file to disk." : "Misslyckades att skriva till disk",
    "A PHP extension stopped the file upload." : "Ett PHP-tillägg stoppade uppladdningen av filen.",
    "No file uploaded" : "Ingen fil uppladdad",
    "Unsupported image type" : "Filtypen är ej giltig",
    "You are already using a custom theme" : "Du använder redan ett annat tema",
    "Theming" : "Teman",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teman gör det möjligt att enkelt skräddarsy utseendet på ditt moln. Detta kommer att synas för alla användare.",
    "Name" : "Namn",
    "Reset to default" : "Återställ till grundinställningar",
    "Web address" : "Webbadress",
    "Web address https://…" : "Webbadress https://...",
    "Slogan" : "Slogan",
    "Color" : "Färg",
    "Logo" : "Logotyp",
    "Upload new logo" : "Ladda upp ny logotyp",
    "Login image" : "Inloggningsbild",
    "Upload new login background" : "Ladda upp ny bakgrundsbild",
    "Remove background image" : "Ta bort bakgrundsbild",
    "reset to default" : "Återställ till standard",
    "Log in image" : "Inloggningsbild"
},
"nplurals=2; plural=(n != 1);");
